@@ -1,22 +1,22 @@
 /*
 
-Copyright (C) 1996-2016 John W. Eaton
+Copyright (C) 1996-2019 John W. Eaton
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -48,10 +48,22 @@ public:
     : sh_lib (), t_checked (), system_fcn_file ()
   { }
 
-  octave_dld_function (octave_builtin::fcn ff, const octave::dynamic_library& shl,
+  octave_dld_function (octave_builtin::fcn ff,
+                       const octave::dynamic_library& shl,
                        const std::string& nm = "",
                        const std::string& ds = "");
 
+  octave_dld_function (octave_builtin::meth mm,
+                       const octave::dynamic_library& shl,
+                       const std::string& nm = "",
+                       const std::string& ds = "");
+
+  // No copying!
+
+  octave_dld_function (const octave_dld_function& fn) = delete;
+
+  octave_dld_function& operator = (const octave_dld_function& fn) = delete;
+
   ~octave_dld_function (void);
 
   void mark_fcn_file_up_to_date (const octave::sys::time& t) { t_checked = t; }
@@ -68,10 +80,15 @@ public:
 
   bool is_dld_function (void) const { return true; }
 
-  static octave_dld_function* create (octave_builtin::fcn ff,
-                                      const octave::dynamic_library& shl,
-                                      const std::string& nm = "",
-                                      const std::string& ds = "");
+  static octave_dld_function * create (octave_builtin::fcn ff,
+                                       const octave::dynamic_library& shl,
+                                       const std::string& nm = "",
+                                       const std::string& ds = "");
+
+  static octave_dld_function * create (octave_builtin::meth mm,
+                                       const octave::dynamic_library& shl,
+                                       const std::string& nm = "",
+                                       const std::string& ds = "");
 
   octave::dynamic_library get_shlib (void) const
   { return sh_lib; }
@@ -89,14 +106,7 @@ private:
   // on the file to see if it has changed.
   bool system_fcn_file;
 
-  // No copying!
-
-  octave_dld_function (const octave_dld_function& fn);
-
-  octave_dld_function& operator = (const octave_dld_function& fn);
-
   DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA
 };
 
 #endif
-
